import fs from "fs";
import { curry } from "ramda";
/**
 * Synchronously reads a CSV file.
 *
 * @func
 * @memberOf Z
 * @category IO
 * @param {String} filepath File path for the CSV file to read
 * @return {df} Zebras dataframe
 * @example
 *
 * Z.readCSV(filepath)
 */

var readCSV = curry(function (filepath) {
  try {
    var data = fs.readFileSync(filepath).toString("utf8");
    var commasStripped = data.replace(/,(?!(?:[^"]*"[^"]*")*[^"]*$)/g, "<COMMA>");
    var dataSplit = commasStripped.split("\n");
    var headers = dataSplit[0].split(",");
    var df = [];

    for (var r = 1; r < dataSplit.length; r += 1) {
      var rowSplit = dataSplit[r].trim().split(",");
      var rowObject = {};

      if (headers.length === rowSplit.length) {
        for (var i = 0; i < rowSplit.length; i += 1) {
          rowObject[headers[i]] = rowSplit[i];
        }

        df.push(rowObject);
      }
    }

    return df;
  } catch (error) {
    return error;
  }
});
export default readCSV;